# jaguar_auth

Authentication interceptors and helper functions for Jaguar. This package builds on 
[`Session`](https://www.dartdocs.org/documentation/jaguar/latest/jaguar/Session-class.html) infrastructure provided
by `jaguar`.

This package provides three types of authentication:

1. [Basic auth][BasicAuth]
2. [Form auth][FormAuth]
3. [JSON auth][JSONAuth]

And an [Authorizer][Authorizer]

# User model

[`AuthorizationUser`][AuthorizationUser] is the base class user models must implement to work with authenticators, 
`Authorizer` and `AuthModelManager`.

[`AuthorizationUser`][AuthorizationUser] demands that the model implements a getter named [`authorizationId`][authorizationId]
that uniquely identifies the model.

Typically, email, username or user id is used as [`authorizationId`][authorizationId] to uniquely identify user models.

## Example

The following user model `User` uses user id as [`authorizationId`][authorizationId]. Notice that `User` implements 
`AuthorizationUser` interface.

```dart
class User implements AuthorizationUser {
  String id;

  String username;

  String password;

  User(this.id, this.username, this.password);

  String get authorizationId => id;
}
```

# Model manager

[`AuthModelManager`][AuthModelManager] is used by authenticators and authorizer to fetch and authenticate the user model.

> TODO

# Authorizer

> TODO

# Basic auth

BasicAuth performs authentication based on [basic authentication](https://en.wikipedia.org/wiki/Basic_access_authentication).

It expects base64 encoded "username:password" pair in "authorization" header with "Basic" scheme.

> TODO

# Form auth

> TODO

# Json auth

> TODO

[BasicAuth]: https://www.dartdocs.org/documentation/jaguar_auth/latest/jaguar_auth/BasicAuth-class.html
[FormAuth]: https://www.dartdocs.org/documentation/jaguar_auth/latest/jaguar_auth/FormAuth-class.html
[JSONAuth]: https://www.dartdocs.org/documentation/jaguar_auth/latest/jaguar_auth/JsonAuth-class.html
[Authorizer]: https://www.dartdocs.org/documentation/jaguar_auth/latest/jaguar_auth/Authorizer-class.html
[AuthModelManager]: https://www.dartdocs.org/documentation/jaguar_auth/latest/jaguar_auth/AuthModelManager-class.html
[AuthorizationUser]: https://www.dartdocs.org/documentation/jaguar_auth/latest/jaguar_auth/AuthorizationUser-class.html
[authorizationId]: https://www.dartdocs.org/documentation/jaguar_auth/latest/jaguar_auth/AuthorizationUser/authorizationId.html